@@ -25,6 +25,26 @@ as.POSIXct.yearqtr <- function(x, tz = "") as.POSIXct(as.Date(x), tz = tz)
 as.POSIXlt.yearqtr <- function(x, tz = "") as.POSIXlt(as.Date(x), tz = tz)
 as.numeric.yearqtr <- function(x, ...) unclass(x)
 as.character.yearqtr <- function(x, ...) format.yearqtr(x, ...)
+as.data.frame.yearqtr <- function(x, row.names = NULL, optional = FALSE, ...) 
+{
+  nrows <- length(x)
+  nm <- paste(deparse(substitute(x), width.cutoff = 500), collapse = " ")
+  if (is.null(row.names)) {
+    if (nrows == 0) 
+        row.names <- character(0)
+    else if(length(row.names <- names(x)) == nrows && !any(duplicated(row.names))) {
+    }
+    else if(optional) row.names <- character(nrows)
+    else row.names <- seq_len(nrows)
+  }
+  names(x) <- NULL
+  value <- list(x)
+  if(!optional) names(value) <- nm
+  attr(value, "row.names") <- row.names
+  class(value) <- "data.frame"
+  value
+}
+
 
 ## other methods for class yearqtr
 c.yearqtr <- function(...)
